@@ -96,7 +96,7 @@ def resize_image_scale(image, max_side):
     scale = max_side / max(image.shape[:2])
 
     # resize the image with the computed scale
-    image = cv2.resize(image, None, fx=scale, fy=scale)
+    image = cv2.resize(image, None, fx=scale, fy=scale, interpolation=cv2.INTER_AREA)
     if image.ndim == 2:
         image = np.expand_dims(image, axis=-1)
 
@@ -175,7 +175,6 @@ def convert_data_type(image, to='uint8'):
 def save_images_batch(images, image_path):
 
     image = np.squeeze(merge_images(images)).astype(np.uint8)
-    image = cv2.cvtColor(image, cv2.COLOR_RGB2BGR)
     cv2.imwrite(image_path, image)
 #----------------------------------------------------------------------------------------------------------------------------------
 
